==> haskell-fsnotify0.3-0.3.0.1-147-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify0.3.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fsnotify
version:              0.3.0.1
visibility:           public
id:                   fsnotify-0.3.0.1-A1Lbi4p5OglBxF8FoKENCp
key:                  fsnotify-0.3.0.1-A1Lbi4p5OglBxF8FoKENCp
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.

category:             Filesystem
abi:                  e628ce5550f0a7774651663d2327d6ea
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux

import-dirs:          /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify0.3
hs-libraries:         HSfsnotify-0.3.0.1-A1Lbi4p5OglBxF8FoKENCp
depends:
    async-2.2.5-GOsAYCd2Rtz3HW1WOZa8a9 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 hinotify-0.4.2-84VjwbZSN6b1RnXJHf4tzI
    shelly-1.11.0-7i4cxL22QU4A1kdRsNmb2O text-2.0.2 time-1.12.2
    unix-2.7.3 unix-compat-0.7.4-HkeMBjDm0rZC7ERiJ32kv5

haddock-interfaces:   /usr/share/doc/haskell-fsnotify0.3/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify0.3/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fsnotify0.3-0.3.0.1-149-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify0.3.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fsnotify
version:              0.3.0.1
visibility:           public
id:                   fsnotify-0.3.0.1-8OB9sPoVpxm1EgcCniXtrc
key:                  fsnotify-0.3.0.1-8OB9sPoVpxm1EgcCniXtrc
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.

category:             Filesystem
abi:                  65a1f0347bfaf76df221a0813245ac6c
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux

import-dirs:          /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify0.3
hs-libraries:         HSfsnotify-0.3.0.1-8OB9sPoVpxm1EgcCniXtrc
depends:
    async-2.2.5-IlWxKJCaUbFHok4DWrcmNB base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 hinotify-0.4.2-G2WL6j0uT0M3mVV8TMlaoV
    shelly-1.11.0-2yYarTNlNYx4VeJwqNCzUw text-2.0.2 time-1.12.2
    unix-2.7.3 unix-compat-0.7.4-6EcuQ5mZqgo5NszRPIcG1

haddock-interfaces:   /usr/share/doc/haskell-fsnotify0.3/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify0.3/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
